@@ -447,5 +447,38 @@ setMethod(f="meanShapes", signature="Coe", definition=
     names(res) <- fl
     return(res)})
 
+# a preliminary version of clust
+setGeneric(name= "clust",def=function(
+  Coe,
+  fac,
+  method = "euclidean",
+  type="fan",
+  palette=col.summer){standardGeneric("clust")})
+
+setMethod(f="clust", signature="Coe", definition=
+            function (Coe,
+                      fac,
+                      method = "euclidean",
+                      type="fan",
+                      palette=col.summer){
+              if (missing(fac)) {
+                if (ncol(Coe@fac)==1) {
+                  fac <- 1
+                  facs <- Coe@fac[, fac]
+                  cols <- palette(nlevels(facs))[facs]
+                } else {
+                  cols <- rep("black", nrow(Coe@coe))}
+              } else {
+                facs <- Coe@fac[, fac]
+                cols <- palette(nlevels(facs))[facs]
+              }
+              
+              Coe.hc <- hclust(dist(Coe@coe, method=method))
+              op <- par(no.readonly = TRUE)
+              par(oma=rep(0, 4), mar=rep(0,4))
+              plot(as.phylo(Coe.hc), tip.color=cols, type=type)
+              par(op)
+              return(Coe.hc)})
+
 # end of Coe.R 
 
